@@ -6,12 +6,12 @@ def gdf(self, query: str, geom_col: str = "geom") -> gpd.GeoDataFrame:
     """
     - Get a `geopandas.GeoDataFrame` from a SQL query
 
-    Args:
+    Arguments:
         query (str): `PostGIS` query as a string
         geom_col (str): geometry column name in the query. Usually `'geom'` or `'shape'`
 
     Returns:
-        query output as GIS data
+        gpd.GeoDataFrame: query output as GIS data
     """
 
     connection = psycopg2.connect(self.uri)
@@ -20,4 +20,4 @@ def gdf(self, query: str, geom_col: str = "geom") -> gpd.GeoDataFrame:
 
     connection.close()
 
-    return gdf
\ No newline at end of file
+    return gdf
